@@ -1,11 +1,12 @@
 package Getopt::Long::EvenLess;
 
-our $DATE = '2017-01-11'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2017-08-09'; # DATE
+our $VERSION = '0.110'; # VERSION
 
-# let's be minimalistic
-#use strict 'subs', 'vars';
-#use warnings;
+# IFUNBUILT
+# # use strict 'subs', 'vars';
+# # use warnings;
+# END IFUNBUILT
 
 our @EXPORT   = qw(GetOptions);
 our @EXPORT_OK = qw(GetOptionsFromArray);
@@ -56,7 +57,7 @@ sub GetOptionsFromArray {
     my %spec_by_opt_name;
     for (keys %spec) {
         my $orig = $_;
-        s/=[fios]\@?\z//;
+        s/=[fios][@%]?\z//;
         s/\|.+//;
         $spec_by_opt_name{$_} = $orig;
     }
@@ -66,7 +67,7 @@ sub GetOptionsFromArray {
         my @candidates;
       OPT_SPEC:
         for my $spec (keys %spec) {
-            $spec =~ s/=[fios]\@?\z//;
+            $spec =~ s/=[fios][@%]?\z//;
             my @opts = split /\|/, $spec;
             for my $o (@opts) {
                 next if $short_mode && length($o) > 1;
@@ -131,7 +132,7 @@ sub GetOptionsFromArray {
 
             my $spec = $spec_by_opt_name{$opt};
             # check whether option requires an argument
-            if ($spec =~ /=[fios]\@?\z/) {
+            if ($spec =~ /=[fios][@%]?\z/) {
                 if (defined $val_in_opt) {
                     # argument is taken after =
                     $code_set_val->($opt, $val_in_opt);
@@ -171,7 +172,7 @@ sub GetOptionsFromArray {
 
                 my $spec = $spec_by_opt_name{$opt};
                 # check whether option requires an argument
-                if ($spec =~ /=[fios]\@?\z/) {
+                if ($spec =~ /=[fios][@%]?\z/) {
                     if (length $str) {
                         # argument is taken from $str
                         $code_set_val->($opt, $str);
@@ -226,7 +227,7 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.10 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-01-11.
+This document describes version 0.110 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-08-09.
 
 =head1 DESCRIPTION
 
@@ -288,23 +289,23 @@ handler, etc.
 
 B<Startup overhead>. Here's a sample startup overhead benchmark:
 
-                           Rate     load_gl      run_gl load_gl_less run_gl_less run_gl_evenless load_gl_evenless   perl
- load_gl          69.45+-0.11/s          --       -1.9%       -69.1%      -69.9%          -81.5%           -82.5% -89.8%
- run_gl           70.77+-0.19/s  1.9+-0.32%          --       -68.5%      -69.3%          -81.2%           -82.2% -89.7%
- load_gl_less      224.7+-2.1/s   223.6+-3%   217.5+-3%           --       -2.5%          -40.2%           -43.5% -67.1%
- run_gl_less       230.4+-1.8/s 231.8+-2.7% 225.6+-2.7%    2.5+-1.2%          --          -38.6%           -42.0% -66.3%
- run_gl_evenless   375.5+-4.6/s 440.7+-6.6% 430.6+-6.6%   67.1+-2.5%  62.9+-2.4%              --            -5.6% -45.1%
- load_gl_evenless  397.6+-2.2/s 472.5+-3.3% 461.8+-3.5%   76.9+-1.9%  72.6+-1.7%       5.9+-1.4%               -- -41.9%
- perl                684+-5.1/s 884.9+-7.6% 866.5+-7.7%  204.4+-3.6% 196.8+-3.2%      82.2+-2.6%         72+-1.6%     --
+                            Rate        run_gl     load_gl load_gl_evenless run_gl_evenless run_gl_less load_gl_less   perl
+ run_gl            63.92+-0.13/s            --       -1.1%           -69.5%          -69.5%      -70.2%       -70.7% -90.8%
+ load_gl           64.65+-0.15/s   1.15+-0.31%          --           -69.1%          -69.2%      -69.8%       -70.3% -90.7%
+ load_gl_evenless  209.55+-0.6/s   227.8+-1.1% 224.1+-1.2%               --           -0.2%       -2.2%        -3.9% -69.9%
+ run_gl_evenless  209.88+-0.53/s   228.3+-1.1% 224.6+-1.1%      0.16+-0.38%              --       -2.1%        -3.7% -69.9%
+ run_gl_less      214.29+-0.47/s 235.24+-0.99% 231.4+-1.1%      2.27+-0.37%      2.1+-0.34%          --        -1.7% -69.3%
+ load_gl_less     217.98+-0.57/s     241+-1.1% 237.1+-1.2%       4.03+-0.4%     3.86+-0.38% 1.72+-0.35%           -- -68.7%
+ perl               696.9+-2.1/s   990.3+-3.9% 977.9+-4.1%      232.6+-1.4%     232.1+-1.3% 225.2+-1.2%  219.7+-1.3%     --
  
  Average times:
-   perl            :     1.4620ms
-   load_gl_evenless:     2.5151ms
-   run_gl_evenless :     2.6631ms
-   run_gl_less     :     4.3403ms
-   load_gl_less    :     4.4504ms
-   run_gl          :    14.1303ms
-   load_gl         :    14.3988ms
+   perl            :     1.4349ms
+   load_gl_less    :     4.5876ms
+   run_gl_less     :     4.6666ms
+   run_gl_evenless :     4.7646ms
+   load_gl_evenless:     4.7721ms
+   load_gl         :    15.4679ms
+   run_gl          :    15.6446ms
 
 =head1 FUNCTIONS
 
@@ -370,7 +371,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
